ufp_aggregate: Aggregate PUFP data

View source: R/aggregate.R

ufp_aggregateR Documentation

Aggregate PUFP data

Description

ufp_aggregate() condenses PUFP time series data to a specified time unit.

Usage

ufp_aggregate(
  df,
  unit = "5 seconds",
  floor_or_celiling = "floor",
  summary_fun = "median"
)

Arguments

df

an object created by ufp_read() or ufp_batch_read().

unit

a character string specifying a time unit or a multiple of a unit to be rounded

floor_or_celiling

either 'floor'(floor_date) or 'ceiling'(ceiling_date). Default = 'floor.'

summary_fun

summary function (i.e. 'mean', 'median'). Default = 'median.'

Value

a tibble

Examples

## Not run: 

ufp_aggregate(df,
  unit = "5 seconds", floor_or_ceiling = "floor",
  summary_fun = "median"
)

## End(Not run)

wolfeclw/pufpR documentation built on April 2, 2022, 9:48 a.m.