ufp_circularize: Calcute circular vairance and clustering

View source: R/circularize.R

ufp_circularizeR Documentation

Calcute circular vairance and clustering

Description

ufp_circularize calculates the circular variance of PUFP measurements and includes arguements to define geographic clustering parameters. Imputing lon/lat values using ufp_impute() or batch_impute_coords() is recommended if GPS coordinates are missing.

Usage

ufp_circularize(
  df,
  circvar_threshold = 0.7,
  window = 60,
  cluster_threshold = NULL,
  show_circvar = FALSE
)

Arguments

df

an object created by ufp_move(). The input data frame must include 'speed' and 'azimuth' before circular variance can be calcuated and clusters can be identified.

circvar_threshold

numeric; Threshold value to use to determine clustering.

window

window (row) used to calculate circular variance.

cluster_threshold

threshold value used to define the number of observations (rows) in each cluster. If the number of points in a cluster is less than this value, they will not be defined as a cluster.

show_circvar

Show circular variance (circvar) within the specified 'window.' Default = 0.7.

Value

a tibble.

Examples

## Not run: 

ufp_circularize(df,
  circvar_threshold = .7, window = 60, cluster_threshold = NULL,
  show_circvar = FALSE
)

## End(Not run)

wolfeclw/pufpR documentation built on April 2, 2022, 9:48 a.m.