ufp_move: Calculate speed and azimuth of PUFP measurements

View source: R/move.R

ufp_moveR Documentation

Calculate speed and azimuth of PUFP measurements

Description

ufp_move() calculates the speed and azimuth (bearing) of consecutive PUFP measurements. If multiple sampling events are included in the input file, the data frame is grouped and speed and azimuth are calcuated by event.

Usage

ufp_move(df)

Arguments

df

data frame created by ufp_read() or ufp_batch_read()

Value

a data frame. Speed is expressed in meters per second; azimuth is expressed in degrees.

Examples

## Not run: 

ufp_move(df)

## End(Not run)

wolfeclw/pufpR documentation built on April 2, 2022, 9:48 a.m.