ufp_read: Read PUFP .txt file

View source: R/read.R

ufp_readR Documentation

Read PUFP .txt file

Description

ufp_read() imports and cleans a PUFP text file.

Usage

ufp_read(
  path,
  tz = "America/New_York",
  truncate_ufp = TRUE,
  coords = TRUE,
  ufp_check = FALSE,
  participant_id = NULL,
  sample_col = NULL,
  sample_id = NULL,
  time_correction = NULL
)

Arguments

path

a path.

tz

a character string that specifies which time zone to parse the date with. Default = 'America/New_York.'

truncate_ufp

truncate UFP concentration? If TRUE (the default), UFP concentrations above 250K will be right censored.

coords

parse GPS string to derive latitude and longitude? Default = TRUE.

ufp_check

check for invalid UFP measurements. If TRUE, new columns named UFP_NA and UFP_Invalid are created to flag missing and potentially invalid UFP concentrations.

participant_id

user defined string to denote a personal identifier. This is useful if the PUFP is deployed during personal sampling. If specified, a new column is created ('ID'). Default is NULL.

sample_col

user defined character string specifying the name of the column to denote sample ID. Default is NULL.

sample_id

user defined string to denote sample ID. If assigned, a value must also be supplied to sample_col. Default is NULL.

time_correction

numeric; second threshold to correct Date_Time using GPS recorded time.

Value

a tibble.

Examples

## Not run: 

ufp_read(path,
  tz = "America/New_York", truncate_ufp = TRUE, coords = TRUE,
  ufp_check = FALSE, participant_id = NULL, sample_col = NULL, sample_id = NULL
)

## End(Not run)

wolfeclw/pufpR documentation built on April 2, 2022, 9:48 a.m.