| ufp_aggregate | R Documentation |
ufp_aggregate() condenses PUFP time series data to a specified time unit.
ufp_aggregate( df, unit = "5 seconds", floor_or_celiling = "floor", summary_fun = "median" )
df |
an object created by |
unit |
a character string specifying a time unit or a multiple of a unit to be rounded |
floor_or_celiling |
either 'floor'( |
summary_fun |
summary function (i.e. 'mean', 'median'). Default = 'median.' |
a tibble
## Not run: ufp_aggregate(df, unit = "5 seconds", floor_or_ceiling = "floor", summary_fun = "median" ) ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.