| ufp_circularize | R Documentation |
ufp_circularize calculates the circular variance of PUFP measurements and
includes arguements to define geographic clustering parameters. Imputing
lon/lat values using ufp_impute() or batch_impute_coords() is
recommended if GPS coordinates are missing.
ufp_circularize( df, circvar_threshold = 0.7, window = 60, cluster_threshold = NULL, show_circvar = FALSE )
df |
an object created by |
circvar_threshold |
numeric; Threshold value to use to determine clustering. |
window |
window (row) used to calculate circular variance. |
cluster_threshold |
threshold value used to define the number of observations (rows) in each cluster. If the number of points in a cluster is less than this value, they will not be defined as a cluster. |
show_circvar |
Show circular variance ( |
a tibble.
## Not run: ufp_circularize(df, circvar_threshold = .7, window = 60, cluster_threshold = NULL, show_circvar = FALSE ) ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.