| ufp_move | R Documentation |
ufp_move() calculates the speed and azimuth (bearing) of consecutive PUFP
measurements. If multiple sampling events are included in the input file, the
data frame is grouped and speed and azimuth are calcuated by event.
ufp_move(df)
df |
data frame created by |
a data frame. Speed is expressed in meters per second; azimuth is expressed in degrees.
## Not run: ufp_move(df) ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.